"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const index = require("./index2.js");
const jsxRuntime = require("react/jsx-runtime");
const react = require("react");
require("@formatjs/intl-localematcher");
require("@formatjs/icu-messageformat-parser");
require("intl-messageformat");
const TranslationContext = react.createContext({
  locale: typeof navigator !== "undefined" ? navigator.language : void 0
});
const TranslationContextProvider = ({ locale, children }) => {
  const value = react.useMemo(() => ({ locale }), [locale]);
  return /* @__PURE__ */ jsxRuntime.jsx(TranslationContext.Provider, { value, children });
};
function useStore(store, ...locales) {
  const [, setCounter] = react.useState(0);
  react.useEffect(() => {
    return store.subscribe(locales, () => {
      setCounter((c) => c + 1);
    });
  }, [store, index.hash(locales)]);
  const dicts = store.getAll(...locales);
  const ref = react.useRef(dicts);
  if (ref.current !== dicts && !index.arrEquals(ref.current, dicts)) {
    ref.current = dicts;
  }
  return ref.current;
}
function createTranslator(options) {
  const store = new index.Store(options);
  const {
    sourceLocale,
    fallbackLocale,
    fallbackToLessSpecific = true,
    fallback: defaultFallback,
    fallbackIgnoresFallbackLocales = false,
    placeholder: defaultPlaceholder,
    warn,
    dateTimeFormatOptions,
    listFormatOptions,
    numberFormatOptions,
    pluralRulesOptions,
    relativeTimeFormatOptions,
    ignoreMissingArgs,
    provideArgs
  } = options;
  function useProvidedArgs() {
    const [args, setArgs] = react.useState(index.resolveProvidedArgs(provideArgs));
    react.useEffect(() => {
      const handles = [];
      for (const [, value] of Object.entries(provideArgs ?? {})) {
        if (typeof value === "object" && value !== null && "subscribe" in value) {
          const handle = value.subscribe(() => {
            setArgs(index.resolveProvidedArgs(provideArgs));
          });
          handles.push(handle);
        }
      }
      return () => {
        for (const handle of handles) {
          handle();
        }
      };
    }, []);
    return args;
  }
  const useTranslator = (overrideLocale) => {
    const contextLocale = react.useContext(TranslationContext).locale;
    const locale = overrideLocale ?? contextLocale ?? sourceLocale;
    const dicts = useStore(store, locale, ...index.calcLocales(locale, fallbackToLessSpecific, fallbackLocale));
    const [sourceDict] = useStore(store, sourceLocale);
    const providedArgs = useProvidedArgs();
    return react.useMemo(() => {
      const t2 = (id, ...[values, options2]) => {
        const fallback = (options2 == null ? void 0 : options2.fallback) ?? defaultFallback;
        const placeholder = (options2 == null ? void 0 : options2.placeholder) ?? defaultPlaceholder;
        return index.translate({
          dicts,
          sourceDict,
          id,
          values,
          fallback,
          fallbackIgnoresFallbackLocales,
          placeholder,
          locale,
          warn,
          cache: store.cache,
          ignoreMissingArgs,
          providedArgs
        });
      };
      return Object.assign(
        t2,
        {
          locale,
          unknown: t2,
          dynamic: t2,
          format(template, ...[values]) {
            return index.format({
              template,
              values,
              locale,
              cache: store.cache,
              ignoreMissingArgs,
              providedArgs
            });
          },
          ...index.intlHelpers({
            cache: store.cache,
            transform: (fn) => fn(locale),
            dateTimeFormatOptions,
            listFormatOptions
          })
        }
      );
    }, [locale, dicts, sourceDict]);
  };
  function TranslatorComponent({
    id,
    values,
    options: options2
  }) {
    const contextLocale = react.useContext(TranslationContext).locale;
    const locale = (options2 == null ? void 0 : options2.locale) ?? contextLocale ?? sourceLocale;
    const dicts = useStore(store, locale, ...index.calcLocales(locale, fallbackToLessSpecific, fallbackLocale));
    const [sourceDict] = useStore(store, sourceLocale);
    const providedArgs = useProvidedArgs();
    const fallback = (options2 == null ? void 0 : options2.fallback) ?? defaultFallback;
    const placeholder = (options2 == null ? void 0 : options2.placeholder) ?? defaultPlaceholder;
    const text = react.useMemo(
      () => index.translate({
        dicts,
        sourceDict,
        id,
        values,
        fallback,
        fallbackIgnoresFallbackLocales,
        placeholder,
        locale,
        warn,
        cache: store.cache,
        ignoreMissingArgs,
        providedArgs
      }),
      [locale, dicts, sourceDict, providedArgs, id, values, fallback, placeholder]
    );
    const textArray = index.castArray(text);
    const Component = (options2 == null ? void 0 : options2.component) ?? react.Fragment;
    return /* @__PURE__ */ jsxRuntime.jsx(jsxRuntime.Fragment, { children: textArray.map((line, index2) => /* @__PURE__ */ jsxRuntime.jsx(Component, { children: line }, index2)) });
  }
  const createTranslatorComponent = (id, ...[values, options2]) => {
    return /* @__PURE__ */ jsxRuntime.jsx(TranslatorComponent, { id, values, options: options2 });
  };
  const RenderComponent = ({
    renderFn,
    dependecies = [renderFn]
  }) => {
    const t2 = useTranslator();
    const providedArgs = useProvidedArgs();
    const value = react.useMemo(
      () => renderFn(t2, {
        providedArgs
      }),
      [t2, providedArgs, ...dependecies]
    );
    return /* @__PURE__ */ jsxRuntime.jsx(jsxRuntime.Fragment, { children: value });
  };
  const render = (renderFn, dependecies) => {
    return /* @__PURE__ */ jsxRuntime.jsx(RenderComponent, { renderFn, dependecies });
  };
  const t = Object.assign(createTranslatorComponent, {
    locale: render((t2) => t2.locale, []),
    unknown: createTranslatorComponent,
    dynamic: createTranslatorComponent,
    format(template, ...[values]) {
      return render(
        (t2, { providedArgs }) => index.format({
          template,
          values,
          locale: t2.locale,
          cache: store.cache,
          ignoreMissingArgs,
          providedArgs
        }),
        [template, index.hash(values)]
      );
    },
    render,
    ...index.intlHelpers({
      cache: store.cache,
      transform: (fn) => render((t2) => fn(t2.locale)),
      dateTimeFormatOptions,
      listFormatOptions,
      numberFormatOptions,
      pluralRulesOptions,
      relativeTimeFormatOptions
    })
  });
  return {
    getTranslator: index.createGetTranslator(store, options),
    useTranslator,
    t,
    clearDicts() {
      store.clear();
    }
  };
}
exports.mergeDicts = index.mergeDicts;
exports.TranslationContext = TranslationContext;
exports.TranslationContextProvider = TranslationContextProvider;
exports.createTranslator = createTranslator;
//# sourceMappingURL=react.js.map
